@@ -1,9 +1,11 @@
 from cerver.utils.log import LOG_TYPE_NONE, cerver_log_both
 
-PERCEPTHOR_VERSION = "0.2.1"
-PERCEPTHOR_VERSION_NAME = "Version 0.2.1"
-PERCEPTHOR_VERSION_DATE = "15/04/2022"
-PERCEPTHOR_VERSION_TIME = "20:21 CST"
+from .lib import lib
+
+PERCEPTHOR_VERSION = "0.5.4"
+PERCEPTHOR_VERSION_NAME = "Version 0.5.4"
+PERCEPTHOR_VERSION_DATE = "09/08/2022"
+PERCEPTHOR_VERSION_TIME = "23:01 CST"
 PERCEPTHOR_VERSION_AUTHOR = "Erick Salas"
 
 version = {
@@ -14,6 +16,10 @@ version = {
 	"author": PERCEPTHOR_VERSION_AUTHOR
 }
 
+percepthor_libauth_version_print_full = lib.percepthor_libauth_version_print_full
+percepthor_libauth_version_print_version_id = lib.percepthor_libauth_version_print_version_id
+percepthor_libauth_version_print_version_name = lib.percepthor_libauth_version_print_version_name
+
 def pypercepthor_version_print_full ():
 	output = "\nPyPercepthor Version: {name}\n" \
 		"Release Date: {date} - {time}\n" \
